@@ -17,6 +17,17 @@ class StrField(Field):
         assert type(v) == str
 
 
+class BoolField(Field):
+    def from_dict(self, v: bool):
+        return bool
+
+    def to_dict(self, v):
+        return v
+
+    def validate_value(self, field_name: str, v):
+        assert type(v) == bool
+
+
 class IntField(Field):
     def from_dict(self, v: int):
         return v
@@ -59,7 +70,7 @@ class ObjectField(Field):
         return self.obj_type(dict=v)
 
     def to_dict(self, v):
-        return v.to_dict()
+        return None if v is None else v.to_dict()
 
     def validate_value(self, field_name: str, v):
         assert isinstance(v, DictAble)
@@ -127,3 +138,14 @@ class EnumField(Field):
             self.enum(v)
         except ValueError as e:
             raise AssertionError('Invalid value')
+
+
+class DictField(Field):
+    def from_dict(self, v):
+        return v
+
+    def to_dict(self, v):
+        return v
+
+    def validate_value(self, field_name: str, v):
+        assert type(v) == dict
